@@ -155,7 +155,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      * MarbleWidget.  The widget will create its own MarbleModel when
      * created.
      */
-    explicit MarbleWidget( QWidget *parent = 0 );
+    explicit MarbleWidget( QWidget *parent = nullptr );
 
     ~MarbleWidget() override;
 
@@ -836,7 +836,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
 
     /**
      * @brief  Set the globe locked to the sub solar point
-     * @param  vsible if globe is locked to the sub solar point
+     * @param  visible if globe is locked to the sub solar point
      */
     void setLockToSubSolarPoint( bool visible );
 
@@ -970,6 +970,22 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     bool showDebugPlacemarks() const;
 
     /**
+     * @brief Set whether to render according to OSM indoor level tags
+     * @param visible visibility of entities (placemarks, buildings etc.) level-wise
+     */
+    void setDebugLevelTags(bool visible);
+
+    bool debugLevelTags() const;
+
+    /**
+     * @brief Set the level to debug
+     * @param level the level to debug
+     */
+    void setLevelToDebug(int level);
+
+    int levelToDebug() const;
+
+        /**
      * @brief Set the map quality for the specified view context.
      *
      * @param quality map quality for the specified view context
@@ -1071,11 +1087,12 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
 
     void framesPerSecond( qreal fps );
 
-    /** This signal is emit when a new rectangle region is selected over the map 
-     *  The list of double values include coordinates in degrees using this order:
-     *  lon1, lat1, lon2, lat2 (or West, North, East, South) as left/top, right/bottom rectangle.
+    /**
+     * This signal is emit when a new rectangle region is selected over the map.
+     *
+     * @param boundingBox The geographical coordinates of the selected region
      */
-    void regionSelected( const QList<double>& );
+    void regionSelected(const GeoDataLatLonBox &boundingBox);
 
     /**
      * This signal is emit when the settings of a plugin changed.
@@ -1150,7 +1167,7 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
     friend class CustomPaintLayer;
 
     friend class MarbleWidgetDefaultInputHandler;
-};
+    };
 
 }
 
